#!/usr/bin/env python
import requests
import json
import login
import findOrCreateDataSet
import findOrCreateMeasurementType
import findOrCreatePropertyType

dataSetName = "DataSetForPythonRefApp"
measurementName = "Voltage"
measurementValue = 3.1
propertyName = "Temperature"
propertyValue = 52.1

def createMeasurement(session, dataSetId, measurementId, value, propId, proValue):
    url = "datasets/" + str(dataSetId) + "/measurements"
    payload = { 'measurementTypeId' : measurementId, 'value' : value, 'properties' : [ {"propertyTypeId": propId, "value": proValue } ] }
    
    print(payload)
    request = session.post(login.base + url, data = json.dumps(payload))
    if request.status_code != requests.codes.no_content:
        request.raise_for_status()
        
    request = session.get(login.base + url)
    if request.status_code == requests.codes.ok:
        return request.json()
    else:
        request.raise_for_status()

def main():
    with requests.Session() as session:
        login.login(session)
        
        dataSetId = findOrCreateDataSet.findDataSet(session, dataSetName)
        if dataSetId <= 0:
            print("data set %s does not exist" % dataSetName)
            return
        
        measurementId = findOrCreateMeasurementType.findMeasurementType(session, dataSetName, measurementName)
        if measurementId <= 0:
            print("measurement type %s for data set %s does not exist" % (measurementName, dataSetName))
            return
    
        propId = findOrCreatePropertyType.findPropertyType(session, dataSetName, propertyName)
        if propId <= 0:
            print("property type %s for data set %s already exists" % (propertyName, dataSetName))
            return

        createMeasurement(session, dataSetId, measurementId, measurementValue, propId, propertyValue);
    
if __name__ == '__main__':
    main()

