#!/usr/bin/env python
import requests
import json
import login
import findOrCreateDataSet
import getMeasurementTypes

dataSetName = "DataSetForPythonRefApp"
measurementName = "Voltage"
units = "V"
upperLimit = "5"
lowerLimit = "-1"

def findMeasurementType(session, dName, mName):
    measurementTypes = getMeasurementTypes.getMeasurementTypes(session, dName)
    for m in measurementTypes:
        if m["name"] == mName:
            return m["id"]
    return 0

def findOrCreateMeasurementType(session, dName, mName, units, uLimit, lLimit):
    if findMeasurementType(session, dName, mName) > 0:
        print("measurement type %s for data set %s already exists" % (mName, dName))
        return
        
    dataSetId = findOrCreateDataSet.findDataSet(session, dName)
    url = "datasets/" + str(dataSetId) + "/measurement-types"
    payload = [ { 'name' : mName, 'units' : units, 'upperLimit' : uLimit, 'lowerLimit' : lLimit } ]
    request = session.post(login.base + url, data = json.dumps(payload))
    if request.status_code == requests.codes.ok:
        data = request.json()
        print(data)
    else:
        request.raise_for_status()
        
def main():
    with requests.Session() as session:
        login.login(session)
        findOrCreateMeasurementType(session, dataSetName, measurementName, units, upperLimit, lowerLimit)
    
if __name__ == '__main__':
    main()

