#!/usr/bin/env python
import requests
import json
import login
import findOrCreateDataSet
import getPropertyTypes

dataSetName = "DataSetForPythonRefApp"
propertyTypeName = "Temperature"
propertyFormat = "Decimal"

def findPropertyType(session, dName, pName):
    types = getPropertyTypes.getPropertyTypes(session, dName)
    for t in types:
        if t["name"] == pName:
            return t["id"]
    return 0

def findOrCreatePropertyType(session, dName, pName, format):
    if findPropertyType(session, dName, pName) > 0:
        print("property type %s for data set %s already exists" % (pName, dName))
        return
        
    dataSetId = findOrCreateDataSet.findDataSet(session, dName)
    url = "datasets/" + str(dataSetId) + "/property-types"
    payload = [ { 'name' : pName, 'format' : format } ]
    request = session.post(login.base + url, data = json.dumps(payload))
    if request.status_code == requests.codes.ok:
        data = request.json()
        print(data)
    else:
        request.raise_for_status()
        
def main():
    with requests.Session() as session:
        login.login(session)
        findOrCreatePropertyType(session, dataSetName, propertyTypeName, propertyFormat)
    
if __name__ == '__main__':
    main()

